@@ -2,6 +2,7 @@ package org.gcube.portlets.user.td.resourceswidget.client;
 
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
+import com.google.gwt.core.client.GWT;
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.widget.core.client.Window;
 import com.sencha.gxt.widget.core.client.event.SelectEvent;
@@ -18,8 +19,10 @@ public class ResourcesListViewDialog extends Window {
 	private static final String WIDTH = "640px";
 	private static final String HEIGHT = "480px";
 	private ResourcesListViewPanel resourcesPanel;
+	private ResourcesMessages msgs;
 
 	public ResourcesListViewDialog(EventBus eventBus) {
+		initMessages();
 		initWindow();
 		resourcesPanel = new ResourcesListViewPanel(
 				eventBus);
@@ -27,13 +30,17 @@ public class ResourcesListViewDialog extends Window {
 		
 		
 	}
+	
+	protected void initMessages() {
+		msgs = GWT.create(ResourcesMessages.class);
+	}
 
 	protected void initWindow() {
 		setWidth(WIDTH);
 		setHeight(HEIGHT);
 		setBodyBorder(false);
 		setResizable(false);
-		setHeadingText("Resources List View");
+		setHeadingText(msgs.resourcesListViewDialogHead());
 		// getHeader().setIcon(Resources.IMAGES.side_list());
 	}
 
